Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(416)

Unified Diff: runtime/vm/isolate.cc

Issue 243973002: - Add a minimal implementation of Capability. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/dart_entry.cc ('k') | runtime/vm/json_stream.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/isolate.cc
===================================================================
--- runtime/vm/isolate.cc (revision 35287)
+++ runtime/vm/isolate.cc (working copy)
@@ -121,16 +121,16 @@
// overcount when other things (gc, compilation) are active.
TIMERSCOPE(isolate_, time_dart_execution);
- // If the message is in band we lookup the receive port to dispatch to. If
- // the receive port is closed, we drop the message without deserializing it.
- Object& receive_port = Object::Handle();
+ // If the message is in band we lookup the handler to dispatch to. If the
+ // receive port was closed, we drop the message without deserializing it.
+ Object& msg_handler = Object::Handle();
if (!message->IsOOB()) {
- receive_port = DartLibraryCalls::LookupReceivePort(message->dest_port());
- if (receive_port.IsError()) {
+ msg_handler = DartLibraryCalls::LookupHandler(message->dest_port());
+ if (msg_handler.IsError()) {
return ProcessUnhandledException(Object::null_instance(),
- Error::Cast(receive_port));
+ Error::Cast(msg_handler));
}
- if (receive_port.IsNull()) {
+ if (msg_handler.IsNull()) {
delete message;
return true;
}
@@ -162,7 +162,7 @@
Service::HandleIsolateMessage(isolate_, msg);
} else {
const Object& result = Object::Handle(
- DartLibraryCalls::HandleMessage(receive_port, msg));
+ DartLibraryCalls::HandleMessage(msg_handler, msg));
if (result.IsError()) {
success = ProcessUnhandledException(msg, Error::Cast(result));
} else {
« no previous file with comments | « runtime/vm/dart_entry.cc ('k') | runtime/vm/json_stream.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698